agent-intergraph.dispatch


build-dispatch-fnclj

(build-dispatch-fn)
(build-dispatch-fn {:keys [manifest fallback-handler]
                    :or {fallback-handler default-passthrough-handler}})

default-passthrough-handlerclj

(default-passthrough-handler request)

error-responseclj

(error-response status error)

introspection-manifestclj


merge-manifestsclj

(merge-manifests & manifests)

Shallow-merge protocol maps and capability maps from left to right.

Shallow-merge protocol maps and capability maps from left to right.
raw docstring

normalize-passthrough-payloadclj

(normalize-passthrough-payload payload normalized-event-data)
(normalize-passthrough-payload payload
                               normalized-event-data
                               {:keys [game-name]})

strip-handlersclj

(strip-handlers manifest)

success-responseclj

(success-response)
(success-response data)

cljdoc builds & hosts documentation for Clojure/Script libraries