(create-app agent-state config)(create-app agent-state config callbacks)(create-app agent-state config callbacks extra-routes)(load-config overrides)(maintain-presence! agent-state config game-name roles)Start a background loop that discovers a game by name and claims a player role. Retries every 10s until the game is found and the player is successfully claimed. roles is a vector of keywords, e.g. [:creator] [:strategist] [:player].
Start a background loop that discovers a game by name and claims a player role. Retries every 10s until the game is found and the player is successfully claimed. roles is a vector of keywords, e.g. [:creator] [:strategist] [:player].
(new-state)(start-agent! agent-state config)(start-agent! agent-state config callbacks)(start-agent! agent-state config callbacks extra-routes)(stop-agent! agent-state config)(storage-push-kv! agent-state config memory)(storage-push-kv! agent-state config memory overrides)(storage-reload! agent-state config)(storage-reload! agent-state config overrides)(submit-action! agent-state config event)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |