(build-dispatch-fn)(build-dispatch-fn {:keys [manifest fallback-handler]
:or {fallback-handler default-passthrough-handler}})(default-passthrough-handler request)(error-response status error)(merge-manifests & manifests)Shallow-merge protocol maps and capability maps from left to right.
Shallow-merge protocol maps and capability maps from left to right.
(normalize-passthrough-payload payload normalized-event-data)(normalize-passthrough-payload payload
normalized-event-data
{:keys [game-name]})(strip-handlers manifest)(success-response)(success-response data)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |